For release notes on version 0.13 and later, [see GitHub](https://github.com/nalgeon/iuliia-py/releases).

## 0.12.0 (2024-01-04)

Added Uzbek transliteration schema (`uz`).

Dropped support for Python below 3.10.

## 0.11.5 (2022-01-11)

Updated Yandex Maps schema.

## 0.11.4 (2021-05-05)

Bumped minimal Python version to 3.7, fixes [#3](https://github.com/nalgeon/iuliia-py/issues/3)

## 0.11.3 (2020-05-05)

Enforced schema encoding, fixes [#1](https://github.com/nalgeon/iuliia-py/issues/1)

## 0.11.2 (2020-05-04)

Split sentence by word boundary.

## 0.11.1 (2020-04-30)

Schema description and Mypy type checking.

## 0.11.0 (2020-04-29)

Moscow Metro map schema.

## 0.10.0 (2020-04-27)

Declarative schema definition.

## 0.9.0 (2020-04-24)

Refactored transliteration schemas into separate package. Nothing changed in external API.

## 0.8.0 (2020-04-23)

UN, scientific and library schemas.

## 0.7.0 (2020-04-22)

ICAO, ISO and telegram schemas.

Mapping capitalization for different cases.

## 0.6.0 (2020-04-21)

GOST and MVD schemas.

## 0.5.0 (2020-04-20)

Command-line interface.

## 0.4.0 (2020-04-20)

Wikipedia and Yandex.Maps schemas.

## 0.3.0 (2020-04-20)

Yandex.Money schema.

## 0.2.1 (2020-04-20)

Basic transliteration features.
